@@ -230,15 +230,16 @@ class fillVars(object, cl_base.glob_attr):
         for replServer in replServers:
             if replServer:
                 md5hex = hashlib.md5(replServer).hexdigest()
+                data8bit = "".join(map(lambda x: str(int(x,16)/2),list(md5hex)))
                 dStart = 0
                 dEnd = 3
                 dMax = 32
-                while(dEnd<=dMax and md5hex[dStart:dEnd] in rids):
+                while(dEnd<=dMax and data8bit[dStart:dEnd] in rids):
                     dStart += 1
                     dEnd +=1
                 if dEnd>=dMax:
                     return ""
-                rids.append(str(int(md5hex[dStart:dEnd],16)))
+                rids.append(data8bit[dStart:dEnd])
         return ",".join(rids)
 
     def get_ld_repl_id(self):
