@@ -142,6 +142,15 @@ class Data:
     # хост отправки
     sr_mail_send_host = {'mode':"w"}
 
+    # включение хранения истории сообщений mail сервиса
+    # по умолчанию выключено
+    sr_mail_history = {'mode':"w",
+                         'value':'off'}
+
+    sr_mail_history_domain = {'mode':"w"}
+
+    sr_mail_history_path = {'mode':"w",
+        'value':"/var/calculate/server-data/samba/share/Mail"}
     # имя компьютера с настроенным сервисом Samba
     sr_samba_host = {}
 
